@@ -53,13 +53,13 @@ impl Display for Output {
         if !self.params.is_empty() {
             write_delim_list(f, &self.params, " (", ")", ", ")?;
         }
-        if let Some(ty) = &self.ty {
+        if let Some(ty) = &self.annotated_type {
             write!(f, ": {}", ty)?;
         }
-        match &self.extend.expr {
+        match &self.annotated_pacing_type {
             None => {},
-            Some(expr) => {
-                write!(f, " @ {}", expr)?;
+            Some(pt) => {
+                write!(f, " @ {}", pt)?;
             },
         }
         if let Some(spawn) = &self.spawn {
@@ -89,8 +89,8 @@ impl Display for SpawnSpec {
         if self.target.is_some() || self.condition.is_some() {
             write!(f, "spawn")?;
         }
-        if let Some(expr) = &self.pacing.expr {
-            write!(f, " @{}", expr)?;
+        if let Some(pt) = &self.annotated_pacing {
+            write!(f, " @{}", pt)?;
         }
         if let Some(target) = &self.target {
             write!(f, " with {}", target)?;
@@ -119,7 +119,7 @@ impl Display for Trigger {
         write!(
             f,
             "trigger{} {}{}",
-            format_opt(&self.extend.expr, " @", ""),
+            format_opt(&self.annotated_pacing_type, " @", ""),
             self.expression,
             format_opt(&self.message, " \"", "\""),
         )?;
